
#ifndef PRISON_EXPORT_H
#define PRISON_EXPORT_H

#ifdef PRISON_STATIC_DEFINE
#  define PRISON_EXPORT
#  define PRISON_NO_EXPORT
#else
#  ifndef PRISON_EXPORT
#    ifdef KF6Prison_EXPORTS
        /* We are building this library */
#      define PRISON_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define PRISON_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef PRISON_NO_EXPORT
#    define PRISON_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef PRISON_DECL_DEPRECATED
#  define PRISON_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef PRISON_DECL_DEPRECATED_EXPORT
#  define PRISON_DECL_DEPRECATED_EXPORT PRISON_EXPORT PRISON_DECL_DEPRECATED
#endif

#ifndef PRISON_DECL_DEPRECATED_NO_EXPORT
#  define PRISON_DECL_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT PRISON_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef PRISON_NO_DEPRECATED
#    define PRISON_NO_DEPRECATED
#  endif
#endif
#include <prison_version.h>

#undef PRISON_DECL_DEPRECATED
#define PRISON_DECL_DEPRECATED [[deprecated]]

#undef PRISON_DECL_DEPRECATED_EXPORT
#define PRISON_DECL_DEPRECATED_EXPORT PRISON_EXPORT PRISON_DECL_DEPRECATED

#undef PRISON_DECL_DEPRECATED_NO_EXPORT
#define PRISON_DECL_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT PRISON_DECL_DEPRECATED

#define PRISON_DECL_DEPRECATED_TEXT(text) [[deprecated(text)]]

/* Take any defaults from group settings */
#if !defined(PRISON_NO_DEPRECATED) && !defined(PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define PRISON_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(PRISON_NO_DEPRECATED_WARNINGS) && !defined(PRISON_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define PRISON_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define PRISON_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(PRISON_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define PRISON_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(PRISON_NO_DEPRECATED)
#  undef PRISON_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT
#elif defined(PRISON_NO_DEPRECATED_WARNINGS)
#  define PRISON_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT
#else
#  define PRISON_DEPRECATED PRISON_DECL_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_DECL_DEPRECATED_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define PRISON_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define PRISON_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef PRISON_NO_DEPRECATED
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT PRISON_VERSION
#endif
#ifdef PRISON_NO_DEPRECATED_WARNINGS
#  define PRISON_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef PRISON_DEPRECATED_WARNINGS_SINCE
#  ifdef PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define PRISON_DEPRECATED_WARNINGS_SINCE PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define PRISON_DEPRECATED_WARNINGS_SINCE PRISON_VERSION
#  endif
#endif

#ifndef PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef PRISON_DEPRECATED
#  define PRISON_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define PRISON_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* PRISON_EXPORT_H */
